==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/HybridOverlayConfigBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HybridOverlayConfigBuilder extends HybridOverlayConfigFluentImpl<HybridOverlayConfigBuilder> implements VisitableBuilder<HybridOverlayConfig,HybridOverlayConfigBuilder>{
  public HybridOverlayConfigBuilder() {
    this(false);
  }
  public HybridOverlayConfigBuilder(Boolean validationEnabled) {
    this(new HybridOverlayConfig(), validationEnabled);
  }
  public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HybridOverlayConfig(), validationEnabled);
  }
  public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent,HybridOverlayConfig instance) {
    this(fluent, instance, false);
  }
  public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent,HybridOverlayConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withHybridClusterNetwork(instance.getHybridClusterNetwork());
      fluent.withHybridOverlayVXLANPort(instance.getHybridOverlayVXLANPort());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HybridOverlayConfigBuilder(HybridOverlayConfig instance) {
    this(instance,false);
  }
  public HybridOverlayConfigBuilder(HybridOverlayConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withHybridClusterNetwork(instance.getHybridClusterNetwork());
      this.withHybridOverlayVXLANPort(instance.getHybridOverlayVXLANPort());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  HybridOverlayConfigFluent<?> fluent;
  Boolean validationEnabled;
  public HybridOverlayConfig build() {
    HybridOverlayConfig buildable = new HybridOverlayConfig(fluent.getHybridClusterNetwork(),fluent.getHybridOverlayVXLANPort());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/HybridOverlayConfigBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HybridOverlayConfigBuilder extends HybridOverlayConfigFluent<HybridOverlayConfigBuilder> implements VisitableBuilder<HybridOverlayConfig,HybridOverlayConfigBuilder>{
  public HybridOverlayConfigBuilder() {
    this(false);
  }
  public HybridOverlayConfigBuilder(Boolean validationEnabled) {
    this(new HybridOverlayConfig(), validationEnabled);
  }
  public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HybridOverlayConfig(), validationEnabled);
  }
  public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent,HybridOverlayConfig instance) {
    this(fluent, instance, false);
  }
  public HybridOverlayConfigBuilder(HybridOverlayConfigFluent<?> fluent,HybridOverlayConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new HybridOverlayConfig());

    if (instance != null) {
      fluent.withHybridClusterNetwork(instance.getHybridClusterNetwork());
      fluent.withHybridOverlayVXLANPort(instance.getHybridOverlayVXLANPort());
      fluent.withHybridClusterNetwork(instance.getHybridClusterNetwork());
      fluent.withHybridOverlayVXLANPort(instance.getHybridOverlayVXLANPort());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HybridOverlayConfigBuilder(HybridOverlayConfig instance) {
    this(instance,false);
  }
  public HybridOverlayConfigBuilder(HybridOverlayConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new HybridOverlayConfig());

    if (instance != null) {
      this.withHybridClusterNetwork(instance.getHybridClusterNetwork());
      this.withHybridOverlayVXLANPort(instance.getHybridOverlayVXLANPort());
      this.withHybridClusterNetwork(instance.getHybridClusterNetwork());
      this.withHybridOverlayVXLANPort(instance.getHybridOverlayVXLANPort());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  HybridOverlayConfigFluent<?> fluent;
  Boolean validationEnabled;
  public HybridOverlayConfig build() {
    HybridOverlayConfig buildable = new HybridOverlayConfig(fluent.buildHybridClusterNetwork(),fluent.getHybridOverlayVXLANPort());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
